@@ -20,7 +20,7 @@ fn get_fake_os_input(fake_win_size: &PositionAndSize) -> FakeInputOutput {
 #[test]
 pub fn starts_with_one_terminal() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -48,7 +48,7 @@ pub fn starts_with_one_terminal() {
 #[test]
 pub fn split_terminals_vertically() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -76,7 +76,7 @@ pub fn split_terminals_vertically() {
 #[test]
 pub fn split_terminals_horizontally() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -105,7 +105,7 @@ pub fn split_terminals_horizontally() {
 pub fn split_largest_terminal() {
     // this finds the largest pane and splits along its longest edge (vertically or horizontally)
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -139,7 +139,7 @@ pub fn split_largest_terminal() {
 #[test]
 pub fn cannot_split_terminals_vertically_when_active_terminal_is_too_small() {
     let fake_win_size = PositionAndSize {
-        columns: 8,
+        cols: 8,
         rows: 20,
         x: 0,
         y: 0,
@@ -167,7 +167,7 @@ pub fn cannot_split_terminals_vertically_when_active_terminal_is_too_small() {
 #[test]
 pub fn cannot_split_terminals_horizontally_when_active_terminal_is_too_small() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 4,
         x: 0,
         y: 0,
@@ -195,7 +195,7 @@ pub fn cannot_split_terminals_horizontally_when_active_terminal_is_too_small() {
 #[test]
 pub fn cannot_split_largest_terminal_when_there_is_no_room() {
     let fake_win_size = PositionAndSize {
-        columns: 8,
+        cols: 8,
         rows: 4,
         x: 0,
         y: 0,
@@ -223,7 +223,7 @@ pub fn cannot_split_largest_terminal_when_there_is_no_room() {
 #[test]
 pub fn scrolling_up_inside_a_pane() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -259,7 +259,7 @@ pub fn scrolling_up_inside_a_pane() {
 #[test]
 pub fn scrolling_down_inside_a_pane() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -297,7 +297,7 @@ pub fn scrolling_down_inside_a_pane() {
 #[test]
 pub fn scrolling_page_up_inside_a_pane() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -332,7 +332,7 @@ pub fn scrolling_page_up_inside_a_pane() {
 #[test]
 pub fn scrolling_page_down_inside_a_pane() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -372,7 +372,7 @@ pub fn max_panes() {
     // with the --max-panes option, we only allow a certain amount of panes on screen
     // simultaneously, new panes beyond this limit will close older panes on screen
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -409,7 +409,7 @@ pub fn max_panes() {
 #[test]
 pub fn toggle_focused_pane_fullscreen() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -452,7 +452,7 @@ pub fn bracketed_paste() {
     // since it's inside a bracketed paste block, while the "QUIT" command is, since it is already
     // past the block
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
