@@ -9,7 +9,7 @@ use crate::CliArgs;
 use crate::tests::utils::commands::{
     CLOSE_PANE_IN_PANE_MODE, ESC, MOVE_FOCUS_IN_PANE_MODE, PANE_MODE, QUIT,
     RESIZE_DOWN_IN_RESIZE_MODE, RESIZE_LEFT_IN_RESIZE_MODE, RESIZE_MODE, RESIZE_UP_IN_RESIZE_MODE,
-    SPLIT_DOWN_IN_PANE_MODE, SPLIT_RIGHT_IN_PANE_MODE,
+    SLEEP, SPLIT_DOWN_IN_PANE_MODE, SPLIT_RIGHT_IN_PANE_MODE,
 };
 use zellij_utils::input::config::Config;
 
@@ -28,7 +28,7 @@ pub fn close_pane_with_another_pane_above_it() {
     // └───────────┘            └───────────┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -70,7 +70,7 @@ pub fn close_pane_with_another_pane_below_it() {
     // └───────────┘            └───────────┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -111,7 +111,7 @@ pub fn close_pane_with_another_pane_to_the_left() {
     // └─────┴─────┘            └──────────┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -151,7 +151,7 @@ pub fn close_pane_with_another_pane_to_the_right() {
     // └─────┴─────┘            └──────────┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -194,7 +194,7 @@ pub fn close_pane_with_multiple_panes_above_it() {
     // └───────────┘            └─────┴─────┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -240,7 +240,7 @@ pub fn close_pane_with_multiple_panes_below_it() {
     // └─────┴─────┘            └─────┴─────┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -284,7 +284,7 @@ pub fn close_pane_with_multiple_panes_to_the_left() {
     // └─────┴─────┘            └──────────┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -330,7 +330,7 @@ pub fn close_pane_with_multiple_panes_to_the_right() {
     // └─────┴─────┘            └──────────┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -374,7 +374,7 @@ pub fn close_pane_with_multiple_panes_above_it_away_from_screen_edges() {
     // └───┴───────┴───┘            └───┴───┴───┴───┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -404,6 +404,7 @@ pub fn close_pane_with_multiple_panes_above_it_away_from_screen_edges() {
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
+        &SLEEP,
         &SPLIT_RIGHT_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
@@ -440,7 +441,7 @@ pub fn close_pane_with_multiple_panes_below_it_away_from_screen_edges() {
     // └───┴───┴───┴───┘            └───┴───┴───┴───┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -464,6 +465,7 @@ pub fn close_pane_with_multiple_panes_below_it_away_from_screen_edges() {
         &PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
+        &SLEEP,
         &SPLIT_RIGHT_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
@@ -504,7 +506,7 @@ pub fn close_pane_with_multiple_panes_to_the_left_away_from_screen_edges() {
     // └────┴──────┘            └────┴──────┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 30,
         x: 0,
         y: 0,
@@ -530,6 +532,7 @@ pub fn close_pane_with_multiple_panes_to_the_left_away_from_screen_edges() {
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
@@ -568,7 +571,7 @@ pub fn close_pane_with_multiple_panes_to_the_right_away_from_screen_edges() {
     // └────┴──────┘            └────┴──────┘
     // █ == pane being closed
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 30,
         x: 0,
         y: 0,
@@ -592,6 +595,7 @@ pub fn close_pane_with_multiple_panes_to_the_right_away_from_screen_edges() {
         &PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
@@ -622,7 +626,7 @@ pub fn close_pane_with_multiple_panes_to_the_right_away_from_screen_edges() {
 #[test]
 pub fn closing_last_pane_exits_app() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
