@@ -20,7 +20,7 @@ fn get_fake_os_input(fake_win_size: &PositionAndSize) -> FakeInputOutput {
 #[test]
 pub fn move_focus_right() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -55,7 +55,7 @@ pub fn move_focus_right() {
 #[test]
 pub fn move_focus_right_to_the_most_recently_used_pane() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -92,7 +92,7 @@ pub fn move_focus_right_to_the_most_recently_used_pane() {
 #[test]
 pub fn move_focus_right_changes_tab() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
