@@ -29,7 +29,7 @@ pub fn resize_down_with_pane_above() {
     // └───────────┘                  └───────────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -73,7 +73,7 @@ pub fn resize_down_with_pane_below() {
     // └───────────┘                  └───────────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -122,7 +122,7 @@ pub fn resize_down_with_panes_above_and_below() {
     // └───────────┘                  └───────────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 25,
         x: 0,
         y: 0,
@@ -169,7 +169,7 @@ pub fn resize_down_with_multiple_panes_above() {
     // └───────────┘                    └───────────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -219,7 +219,7 @@ pub fn resize_down_with_panes_above_aligned_left_with_current_pane() {
     // └─────┴─────┘                    └─────┴─────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -271,7 +271,7 @@ pub fn resize_down_with_panes_below_aligned_left_with_current_pane() {
     // └─────┴─────┘                    └─────┴─────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -322,7 +322,7 @@ pub fn resize_down_with_panes_above_aligned_right_with_current_pane() {
     // └─────┴─────┘                    └─────┴─────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -371,7 +371,7 @@ pub fn resize_down_with_panes_below_aligned_right_with_current_pane() {
     // └─────┴─────┘                    └─────┴─────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -421,7 +421,7 @@ pub fn resize_down_with_panes_above_aligned_left_and_right_with_current_pane() {
     // └───┴───┴───┘                    └───┴───┴───┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -438,6 +438,7 @@ pub fn resize_down_with_panes_above_aligned_left_and_right_with_current_pane() {
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &RESIZE_MODE,
         &RESIZE_DOWN_IN_RESIZE_MODE,
@@ -474,7 +475,7 @@ pub fn resize_down_with_panes_below_aligned_left_and_right_with_current_pane() {
     // └───┴───┴───┘                    └───┴───┴───┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -491,6 +492,7 @@ pub fn resize_down_with_panes_below_aligned_left_and_right_with_current_pane() {
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
@@ -529,7 +531,7 @@ pub fn resize_down_with_panes_above_aligned_left_and_right_with_panes_to_the_lef
     // └─┴─┴───┴─┴─┘                    └─┴─┴───┴─┴─┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 40,
         x: 0,
         y: 0,
@@ -547,10 +549,12 @@ pub fn resize_down_with_panes_above_aligned_left_and_right_with_panes_to_the_lef
         &RESIZE_LEFT_IN_RESIZE_MODE,
         &RESIZE_LEFT_IN_RESIZE_MODE,
         &PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
@@ -601,7 +605,7 @@ pub fn resize_down_with_panes_below_aligned_left_and_right_with_to_the_left_and_
     // └─┴───────┴─┘                    └─┴───────┴─┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 40,
         x: 0,
         y: 0,
@@ -619,6 +623,7 @@ pub fn resize_down_with_panes_below_aligned_left_and_right_with_to_the_left_and_
         &RESIZE_LEFT_IN_RESIZE_MODE,
         &RESIZE_LEFT_IN_RESIZE_MODE,
         &PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
@@ -673,7 +678,7 @@ pub fn cannot_resize_down_when_pane_below_is_at_minimum_height() {
     // └───────────┘                  └───────────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 7,
         x: 0,
         y: 0,
