@@ -27,7 +27,7 @@ pub fn resize_up_with_pane_above() {
     // └───────────┘                └───────────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -71,7 +71,7 @@ pub fn resize_up_with_pane_below() {
     // └───────────┘                └───────────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -119,7 +119,7 @@ pub fn resize_up_with_panes_above_and_below() {
     // └───────────┘                └───────────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -165,7 +165,7 @@ pub fn resize_up_with_multiple_panes_above() {
     // └───────────┘                 └───────────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -213,7 +213,7 @@ pub fn resize_up_with_panes_above_aligned_left_with_current_pane() {
     // └─────┴─────┘                  └─────┴─────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -265,7 +265,7 @@ pub fn resize_up_with_panes_below_aligned_left_with_current_pane() {
     // └─────┴─────┘                  └─────┴─────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -316,7 +316,7 @@ pub fn resize_up_with_panes_above_aligned_right_with_current_pane() {
     // └─────┴─────┘                  └─────┴─────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -365,7 +365,7 @@ pub fn resize_up_with_panes_below_aligned_right_with_current_pane() {
     // └─────┴─────┘                  └─────┴─────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -415,7 +415,7 @@ pub fn resize_up_with_panes_above_aligned_left_and_right_with_current_pane() {
     // └───┴───┴───┘                  └───┴───┴───┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -432,6 +432,7 @@ pub fn resize_up_with_panes_above_aligned_left_and_right_with_current_pane() {
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &RESIZE_MODE,
         &RESIZE_UP_IN_RESIZE_MODE,
@@ -468,7 +469,7 @@ pub fn resize_up_with_panes_below_aligned_left_and_right_with_current_pane() {
     // └───┴───┴───┘                  └───┴───┴───┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -485,6 +486,7 @@ pub fn resize_up_with_panes_below_aligned_left_and_right_with_current_pane() {
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
@@ -523,7 +525,7 @@ pub fn resize_up_with_panes_above_aligned_left_and_right_with_panes_to_the_left_
     // └─┴─┴───┴─┴─┘                  └─┴─┴───┴─┴─┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 40,
         x: 0,
         y: 0,
@@ -541,10 +543,12 @@ pub fn resize_up_with_panes_above_aligned_left_and_right_with_panes_to_the_left_
         &RESIZE_LEFT_IN_RESIZE_MODE,
         &RESIZE_LEFT_IN_RESIZE_MODE,
         &PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
@@ -595,7 +599,7 @@ pub fn resize_up_with_panes_below_aligned_left_and_right_with_to_the_left_and_ri
     // └─┴───────┴─┘                  └─┴───────┴─┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 40,
         x: 0,
         y: 0,
@@ -613,6 +617,7 @@ pub fn resize_up_with_panes_below_aligned_left_and_right_with_to_the_left_and_ri
         &RESIZE_LEFT_IN_RESIZE_MODE,
         &RESIZE_LEFT_IN_RESIZE_MODE,
         &PANE_MODE,
+        &SLEEP,
         &SPLIT_DOWN_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
         &MOVE_FOCUS_IN_PANE_MODE,
@@ -667,7 +672,7 @@ pub fn cannot_resize_up_when_pane_above_is_at_minimum_height() {
     // └───────────┘                └───────────┘
     // █ == focused pane
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 7,
         x: 0,
         y: 0,
