@@ -21,7 +21,7 @@ fn get_fake_os_input(fake_win_size: &PositionAndSize) -> FakeInputOutput {
 #[test]
 pub fn open_new_tab() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -56,7 +56,7 @@ pub fn open_new_tab() {
 #[test]
 pub fn switch_to_prev_tab() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -92,7 +92,7 @@ pub fn switch_to_prev_tab() {
 #[test]
 pub fn switch_to_next_tab() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -128,7 +128,7 @@ pub fn switch_to_next_tab() {
 #[test]
 pub fn close_tab() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -164,7 +164,7 @@ pub fn close_tab() {
 #[test]
 pub fn close_last_pane_in_a_tab() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -201,7 +201,7 @@ pub fn close_last_pane_in_a_tab() {
 #[test]
 pub fn close_the_middle_tab() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -240,7 +240,7 @@ pub fn close_the_middle_tab() {
 #[test]
 pub fn close_the_tab_that_has_a_pane_in_fullscreen() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -284,7 +284,7 @@ pub fn close_the_tab_that_has_a_pane_in_fullscreen() {
 #[test]
 pub fn closing_last_tab_exits_the_app() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
