@@ -15,7 +15,7 @@ fn get_fake_os_input(fake_win_size: &PositionAndSize) -> FakeInputOutput {
 #[test]
 pub fn window_width_decrease_with_one_pane() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -24,7 +24,7 @@ pub fn window_width_decrease_with_one_pane() {
     let mut fake_input_output = get_fake_os_input(&fake_win_size);
     fake_input_output.add_terminal_input(&[&QUIT]);
     fake_input_output.add_sigwinch_event(PositionAndSize {
-        columns: 90,
+        cols: 90,
         rows: 20,
         x: 0,
         y: 0,
@@ -51,7 +51,7 @@ pub fn window_width_decrease_with_one_pane() {
 #[test]
 pub fn window_width_increase_with_one_pane() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -60,7 +60,7 @@ pub fn window_width_increase_with_one_pane() {
     let mut fake_input_output = get_fake_os_input(&fake_win_size);
     fake_input_output.add_terminal_input(&[&QUIT]);
     fake_input_output.add_sigwinch_event(PositionAndSize {
-        columns: 141,
+        cols: 141,
         rows: 20,
         x: 0,
         y: 0,
@@ -87,7 +87,7 @@ pub fn window_width_increase_with_one_pane() {
 #[test]
 pub fn window_height_increase_with_one_pane() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -96,7 +96,7 @@ pub fn window_height_increase_with_one_pane() {
     let mut fake_input_output = get_fake_os_input(&fake_win_size);
     fake_input_output.add_terminal_input(&[&QUIT]);
     fake_input_output.add_sigwinch_event(PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 30,
         x: 0,
         y: 0,
@@ -123,7 +123,7 @@ pub fn window_height_increase_with_one_pane() {
 #[test]
 pub fn window_width_and_height_decrease_with_one_pane() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -132,7 +132,7 @@ pub fn window_width_and_height_decrease_with_one_pane() {
     let mut fake_input_output = get_fake_os_input(&fake_win_size);
     fake_input_output.add_terminal_input(&[&QUIT]);
     fake_input_output.add_sigwinch_event(PositionAndSize {
-        columns: 90,
+        cols: 90,
         rows: 10,
         x: 0,
         y: 0,
