@@ -19,7 +19,7 @@ fn get_fake_os_input(fake_win_size: &PositionAndSize) -> FakeInputOutput {
 #[test]
 pub fn adding_new_terminal_in_fullscreen() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
@@ -54,7 +54,7 @@ pub fn adding_new_terminal_in_fullscreen() {
 #[test]
 pub fn move_focus_is_disabled_in_fullscreen() {
     let fake_win_size = PositionAndSize {
-        columns: 121,
+        cols: 121,
         rows: 20,
         x: 0,
         y: 0,
