@@ -158,7 +158,8 @@ pub(crate) fn zellij_exports(store: &Store, plugin_env: &PluginEnv) -> ImportObj
         host_subscribe,
         host_unsubscribe,
         host_set_invisible_borders,
-        host_set_max_height,
+        host_set_fixed_height,
+        host_set_fixed_width,
         host_set_selectable,
         host_get_plugin_ids,
         host_open_file,
@@ -189,13 +190,24 @@ fn host_set_selectable(plugin_env: &PluginEnv, selectable: i32) {
         .unwrap()
 }
 
-fn host_set_max_height(plugin_env: &PluginEnv, max_height: i32) {
-    let max_height = max_height as usize;
+fn host_set_fixed_height(plugin_env: &PluginEnv, fixed_height: i32) {
+    let fixed_height = fixed_height as usize;
     plugin_env
         .senders
-        .send_to_screen(ScreenInstruction::SetMaxHeight(
+        .send_to_screen(ScreenInstruction::SetFixedHeight(
             PaneId::Plugin(plugin_env.plugin_id),
-            max_height,
+            fixed_height,
+        ))
+        .unwrap()
+}
+
+fn host_set_fixed_width(plugin_env: &PluginEnv, fixed_width: i32) {
+    let fixed_width = fixed_width as usize;
+    plugin_env
+        .senders
+        .send_to_screen(ScreenInstruction::SetFixedWidth(
+            PaneId::Plugin(plugin_env.plugin_id),
+            fixed_width,
         ))
         .unwrap()
 }
