@@ -2,6 +2,7 @@
 use crate::cli::Command;
 use serde::{Deserialize, Serialize};
 use structopt::StructOpt;
+use zellij_tile::data::InputMode;
 
 #[derive(Clone, Default, Debug, PartialEq, Deserialize, Serialize, StructOpt)]
 /// Options that can be set either through the config file,
@@ -10,7 +11,14 @@ pub struct Options {
     /// Allow plugins to use a more simplified layout
     /// that is compatible with more fonts
     #[structopt(long)]
+    #[serde(default)]
     pub simplified_ui: bool,
+    /// Set the default theme
+    #[structopt(long)]
+    pub theme: Option<String>,
+    /// Set the default mode
+    #[structopt(long)]
+    pub default_mode: Option<InputMode>,
 }
 
 impl Options {
@@ -32,7 +40,21 @@ impl Options {
             self.simplified_ui
         };
 
-        Options { simplified_ui }
+        let default_mode = match other.default_mode {
+            None => self.default_mode,
+            other => other,
+        };
+
+        let theme = match other.theme {
+            None => self.theme.clone(),
+            other => other,
+        };
+
+        Options {
+            simplified_ui,
+            theme,
+            default_mode,
+        }
     }
 
     pub fn from_cli(&self, other: Option<Command>) -> Options {
